pub struct Field<'a> { /* private fields */ }Expand description
Entire HTTP field line, excluding any trailing CRLF.
field-line = field-name ":" OWS field-value OWSThe parsed field-value excludes surrounding optional whitespace.
Implementations
Sourceimpl<'a> Field<'a>
impl<'a> Field<'a>
Sourcepub fn try_from_slice(input: &'a [u8]) -> Result<Self, ErrMode<ContextError>>
pub fn try_from_slice(input: &'a [u8]) -> Result<Self, ErrMode<ContextError>>
Parses an entire HTTP field line from bytes, excluding the trailing CRLF.
Sourcepub fn name_indices(&self) -> Range<usize>
pub fn name_indices(&self) -> Range<usize>
Returns the byte indices of the field name.
Sourcepub fn value_indices(&self) -> Range<usize>
pub fn value_indices(&self) -> Range<usize>
Returns the byte indices of the trimmed field value.
Sourcepub fn value(&self) -> FieldValue<'a>
pub fn value(&self) -> FieldValue<'a>
Returns the parsed field value.